Learn R Programming

polySegratio (version 0.2-6)

divide.autoMarkers: Divide markers by parental type

Description

Given markers (or more correctly dominant 1,0) marker data and return list object of containing markers data split according to parental alleles, namely 1,0 for each parent and 1,1 for both parents

Usage

divide.autoMarkers(markers, description = paste("Markers split for",
deparse(substitute(markers))), parent.cols = c(1, 2),
extra.cols = NULL, cols.drop = c(parent.cols, extra.cols))

Value

Returns S3 class divideAutoMarkers containing

p10, p01, p11

lists for where the first, second components are heterozygous for parents 1, 2 and both resp. Each list contains

  • description text containing a description for printing

  • parent label for parent

  • markers markers for specified parental type (including parents etc)

  • extras extra columns subsetted (if specified)

  • seg.ratios segregation ratios as class segRatio

Arguments

markers

matrix of 1, 0, NA indicating marker alleles where rownames are markernames, column names are progeny names

description

text containing a description for printing

parent.cols

column(s) for parental markers (default: 1,2)

extra.cols

extra column(s) to be subsetted (default: NULL)

cols.drop

columns to be dropped from markers before splitting data which can be set to NULL if no columns are to be dropped (Default: c(parent.cols,extra.cols))

Author

Peter Baker drpetebaker@gmail.com

See Also

segRatio, sim.autoCross

Examples

Run this code

p2 <- sim.autoCross(4,
dose.proportion=list(p01=c(0.7,0.3),p10=c(0.7,0.3),
                     p11=c(0.6,0.2,0.2)))
print(p2)

ss <- divide.autoMarkers(p2$markers)

print(ss)

Run the code above in your browser using DataLab