Learn R Programming

polySegratio (version 0.2-6)

divideAutoMarkers: S3 class divideAutoMarkers

Description

An S3 class which contains marker data and segregation proportions split into three groups corresponding to parents with ‘01’, ‘10’ and ‘11’ markers

Arguments

Value

p10, p01, p11

lists for where the first, second components are heterozygous for parents 1, 2 and both resp. Each list contains

  • description text containing a description for printing

  • parent label for parent

  • markers markers for specified parental type including parents etc

  • extras extra columns subsetted (if specified)

  • seg.ratios segregation ratios as class segRatio

Author

Peter Baker drpetebaker@gmail.com

See Also

segRatio, sim.autoCross

Examples

Run this code
p2 <- sim.autoCross(4, dose.proportion=list(p01=c(0.7,0.3),p10=c(0.7,0.3),
                                            p11=c(0.6,0.2,0.2)))
print(p2)
ss <- divide.autoMarkers(p2$markers)
print(ss)

Run the code above in your browser using DataLab