Learn R Programming

polySegratio (version 0.2-6)

expected.segRatio: Compute theoretical segregation proportions for regular autopolyploids

Description

Expected segregation proportions for various dosages of dominant markers for regular autopolyploids are calculated using the formula of Ripol et al (1999) based on Haldane (1930) for single dose and multiple dose parents cross nulliplex ("homozygous") and an unpublished formula where both parents possess at least single dose markers ("heterogeneous")

Usage

expected.segRatio(ploidy.level = stop("No ploidy level set"),
type.parents = c("heterogeneous", "homozygous"))

Value

ratio

vector of proportions for each dosage

ploidy.level

numeric value of ploidy level 2,4,6,8, ...

ploidy.name

name of ploidy

Arguments

ploidy.level

the number of homologous chromosomes, either as numeric or as a character string

type.parents

"heterogeneous" if parental markers are 0,1 or "homogeneous" if parental markers are both 1

Author

Peter Baker drpetebaker@gmail.com

Warning

While results will be returned if the ploidy level is set as an odd number, the formula used are only for even numbers.

References

Haldane, J. B. S. (1930) Theoretical genetics of autopolyploids. Journal of genetics 22 359--372

Ripol, M I et al (1999) Statistical aspects of genetic mapping in autopolyploids. Gene 235 31--41

See Also

segRatio, test.segRatio

Examples

Run this code
## heterogeneous parents

expected.segRatio(2)
expected.segRatio("Tetraploid")
expected.segRatio("tEtR")
expected.segRatio("octo")
expected.segRatio("Octa")
expected.segRatio(14)
## warning
expected.segRatio(9)

## errors - not run
## expected.segRatio("abcd")
## expected.segRatio(-1)

## homogeneous parents

expected.segRatio("Octa", type.parents="heter")
expected.segRatio("Octa", type.parents="homo")
expected.segRatio("tetra", type.parents="homo")
expected.segRatio(6, type.parents="homo")
expected.segRatio(9, type.parents="homo")

Run the code above in your browser using DataLab